==> dsgui-1.0-rc1.tar.gz: dsgui-1.0-rc1/ds_send.py <==
# encoding: utf-8

#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

"""
Here resides a separate dialog for finding Data Boxes
"""

import pygtk
import gtk
pygtk.require("2.0")
from dslib import models
from ds_search import DsSearchDialog
import os
import mimetypes
import sys


class DsSendDialog(object):

  def __init__(self, parent, recipient=None, subject=None):
    """
    client = dslib client instance
    recipient will be the default recipient,
    subject will be the default subject
    """
    self.parent = parent
    self.builder = gtk.Builder()
    gui_xml = self.parent.fix_ui_xml("ds_send.ui")
    try:
      self.builder.add_from_string(gui_xml.decode('utf-8'))
    except:
      # this fixes problem with different API on windows and PyGTK 2.12
      self.builder.add_from_string(gui_xml.decode('utf-8'), -1)
    self.builder.connect_signals(self)
    self.dialog = self.builder.get_object("send_message_dialog")
    self.add_recipients_button = self.builder.get_object("add_recipients_button")
    self.recipient_store = self.builder.get_object("recipient_store")
    self.recipient_treeview = self.builder.get_object("recipient_treeview")
    self.attachment_store = self.builder.get_object("attachment_store")
    self.attachment_treeview = self.builder.get_object("attachment_treeview")
    self.metatype_store = self.builder.get_object("metatype_store")
    self.subject_entry = self.builder.get_object("subject_entry")
    self.send_button = self.builder.get_object("send_button")
    self.recipient = recipient
    self.subject = subject

  def run(self):
    self.dialog.show()
    if self.recipient:
      info = models.dbOwnerInfo()
      info.dbType = "OVM"
      info.dbID = self.recipient
      error_message=_("It was not possible to download data about the sender '%s'."
                      %self.recipient)
      error_message += "\n\n" + _("Please fill in the recipient by hand.")
      reply, error = self.parent.try_client_method("FindDataBox",
                                                   (info,),
                                                   error_message=error_message,
                                                   show_exception_details=False,
                                                   handle_status=False,
                                                   parent=self.dialog,
                                                   async=True)
      if not error:
        for box in reply.data:
          self.recipient_store.append([box.dbID,box.firmName,box.adCity])
    if self.subject:
      self.subject_entry.set_text(self.subject)
    result = self.dialog.run()
    return result

  def destroy(self):
    self.dialog.destroy()

  def hide(self):
    self.dialog.hide()
    
  def show_all(self):
    self.dialog.show_all()

  # ========== Callbacks ==========

  def on_add_recipients_button_clicked(self, w):
    d = DsSearchDialog(self.parent)
    result = d.run()
    d.hide()
    if result == 1:
      boxes = d.get_selected_box_names()
      for box in boxes:
        print box
        self.recipient_store.append([box[0],box[1],box[2]])
    self._check_requisities()

  def on_add_attachment_button_clicked(self, w):
    d = gtk.FileChooserDialog(title="Select an attachment file",
                              parent=self.dialog,
                              action=gtk.FILE_CHOOSER_ACTION_OPEN,
                              buttons=(gtk.STOCK_OK,gtk.RESPONSE_ACCEPT,
                                       gtk.STOCK_CANCEL,gtk.RESPONSE_REJECT)
                              )
    ok = d.run()
    if ok == gtk.RESPONSE_ACCEPT:
      import os
      fullname = d.get_filename()
      dir, name = os.path.split(fullname)
      mimetype, encoding = mimetypes.guess_type(fullname)
      if mimetype == "application/xml":
        mimetype = "text/xml"
      x = self.attachment_store.append([name, fullname, 0, mimetype])
    d.destroy()
    self._check_requisities()


  def on_subject_entry_changed(self, w):
    self._check_requisities()

  def on_recipients_treeview_key_release_event(self, w, event):
    if event.keyval == gtk.keysyms.Delete:
      treeview = self.recipient_treeview
      model, paths = treeview.get_selection().get_selected_rows()
      if len(paths) == 1:
        model.remove(model.get_iter(paths[0]))
        self._check_requisities()

  def on_attachment_treeview_key_release_event(self, w, event):
    if event.keyval == gtk.keysyms.Delete:
      treeview = self.attachment_treeview
      model, paths = treeview.get_selection().get_selected_rows()
      if len(paths) == 1:
        model.remove(model.get_iter(paths[0]))
        self._check_requisities()
    
  # ======== end of Callbacks =========


  def _check_requisities(self):
    """check if all mandatory fields are filled. If yes, activate the OK button"""
    text_ok = False
    recipients_ok = False
    attachments_ok = False
    if self.subject_entry.get_text():
      text_ok = True
    if len(self.recipient_store) > 0:
      recipients_ok = True
    if len(self.attachment_store) > 0:
      attachments_ok = True
    all_ok = text_ok and recipients_ok and attachments_ok
    if all_ok:
      self.send_button.set_sensitive(True)
    else:
      self.send_button.set_sensitive(False)
      
  def get_prepared_message(self):
    import base64
    envelope = models.dmEnvelope()
    envelope.dbIDRecipient = self.recipient_store[0][0]
    envelope.dmAnnotation = self.builder.get_object("subject_entry").get_text()
    for name in ("dmLegalTitleLaw","dmLegalTitleYear","dmLegalTitleSect","dmLegalTitlePar",
                 "dmLegalTitlePoint","dmRecipientRefNumber","dmRecipientIdent",
                 "dmSenderRefNumber","dmSenderIdent","dmToHands"):
      text = self.builder.get_object(name).get_text()
      if text:
        setattr(envelope, name, text)
    envelope.dmPersonalDelivery = self.builder.get_object("dmPersonalDelivery").get_active()
    dmfiles = []
    for row in self.attachment_store:
      dmfile = models.dmFile()
      dmfile._dmMimeType = row[3]      
      dmfile._dmFileMetaType = "main"
      dmfile._dmFileDescr = row[0]
      f = file(row[1].decode('utf-8').encode(sys.getfilesystemencoding()), "r")
      dmfile.dmEncodedContent = base64.standard_b64encode(f.read())
      f.close()
      dmfiles.append(dmfile)
    return envelope, dmfiles

==> dsgui-1.1.2.tar.gz: dsgui-1.1.2/ds_send.py <==
# encoding: utf-8

#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

"""
Here resides a separate dialog for finding Data Boxes
"""

import pygtk
import gtk
pygtk.require("2.0")
from dslib import models
from ds_search import DsSearchDialog
import os
import mimetypes
import sys
import os_support


class DsSendDialog(object):

  _last_dir = None

  def __init__(self, parent, recipient=None, subject=None):
    """
    client = dslib client instance
    recipient will be the default recipient,
    subject will be the default subject
    """
    self.parent = parent
    self.builder = gtk.Builder()
    gui_xml = self.parent.fix_ui_xml("ds_send.ui")
    try:
      self.builder.add_from_string(gui_xml.decode('utf-8'))
    except:
      # this fixes problem with different API on windows and PyGTK 2.12
      self.builder.add_from_string(gui_xml.decode('utf-8'), -1)
    self.builder.connect_signals(self)
    self.dialog = self.builder.get_object("send_message_dialog")
    self.add_recipients_button = self.builder.get_object("add_recipients_button")
    self.recipient_store = self.builder.get_object("recipient_store")
    self.recipient_treeview = self.builder.get_object("recipient_treeview")
    self.attachment_store = self.builder.get_object("attachment_store")
    self.attachment_treeview = self.builder.get_object("attachment_treeview")
    self.metatype_store = self.builder.get_object("metatype_store")
    self.subject_entry = self.builder.get_object("subject_entry")
    self.send_button = self.builder.get_object("send_button")
    self.recipient = recipient
    self.subject = subject
    self.dialog.set_transient_for(self.parent.window1)

  def run(self):
    self.dialog.show()
    if self.recipient:
      info = models.dbOwnerInfo()
      info.dbType = "OVM"
      info.dbID = self.recipient
      error_message=_("It was not possible to download data about the sender '%s'."
                      %self.recipient)
      error_message += "\n\n" + _("Please fill in the recipient by hand.")
      reply, error = self.parent.try_client_method("FindDataBox",
                                                   (info,),
                                                   error_message=error_message,
                                                   show_exception_details=False,
                                                   handle_status=False,
                                                   parent=self.dialog,
                                                   async=True)
      if not error:
        for box in reply.data:
          self.recipient_store.append([box.dbID,box.firmName,box.adCity])
    if self.subject:
      self.subject_entry.set_text(self.subject)
    result = self.dialog.run()
    return result

  def destroy(self):
    self.dialog.destroy()

  def hide(self):
    self.dialog.hide()
    
  def show_all(self):
    self.dialog.show_all()

  # ========== Callbacks ==========

  def on_add_recipients_button_clicked(self, w):
    d = DsSearchDialog(self.parent, trans_window=self.dialog)
    result = d.run()
    d.hide()
    if result == 1:
      boxes = d.get_selected_box_names()
      for box in boxes:
        self.recipient_store.append([box[0],box[1],box[2]])
    self._check_requisities()

  def on_add_attachment_button_clicked(self, w):
    d = gtk.FileChooserDialog(title="Select an attachment file",
                              parent=self.dialog,
                              action=gtk.FILE_CHOOSER_ACTION_OPEN,
                              buttons=(gtk.STOCK_OK,gtk.RESPONSE_ACCEPT,
                                       gtk.STOCK_CANCEL,gtk.RESPONSE_REJECT)
                              )
    if DsSendDialog._last_dir:
      open_dir = DsSendDialog._last_dir
    else:
      open_dir = os_support.get_home_dir("./") 
    d.set_current_folder(open_dir)
    ok = d.run()
    if ok == gtk.RESPONSE_ACCEPT:
      import os
      fullname = d.get_filename()
      dir, name = os.path.split(fullname)
      # save the directory for the next run
      DsSendDialog._last_dir = dir
      mimetype, encoding = mimetypes.guess_type(fullname)
      if mimetype == "application/xml":
        mimetype = "text/xml"
      if not mimetype:
        if name.endswith(".zfo"):
          mimetype = "application/zip"
        else:
          mimetype = "text/plain"
      x = self.attachment_store.append([name, fullname, 0, mimetype])
    d.destroy()
    self._check_requisities()


  def on_subject_entry_changed(self, w):
    self._check_requisities()

  def on_recipients_treeview_key_release_event(self, w, event):
    if event.keyval == gtk.keysyms.Delete:
      treeview = self.recipient_treeview
      model, paths = treeview.get_selection().get_selected_rows()
      if len(paths) == 1:
        model.remove(model.get_iter(paths[0]))
        self._check_requisities()

  def on_attachment_treeview_key_release_event(self, w, event):
    if event.keyval == gtk.keysyms.Delete:
      treeview = self.attachment_treeview
      model, paths = treeview.get_selection().get_selected_rows()
      if len(paths) == 1:
        model.remove(model.get_iter(paths[0]))
        self._check_requisities()
    
  def on_mimetype_cellrenderer_edited(self, w, row, new_value):
    self.attachment_store[row][3] = new_value
    
  # ======== end of Callbacks =========


  def _check_requisities(self):
    """check if all mandatory fields are filled. If yes, activate the OK button"""
    text_ok = False
    recipients_ok = False
    attachments_ok = False
    if self.subject_entry.get_text():
      text_ok = True
    if len(self.recipient_store) > 0:
      recipients_ok = True
    if len(self.attachment_store) > 0:
      attachments_ok = True
    all_ok = text_ok and recipients_ok and attachments_ok
    if all_ok:
      self.send_button.set_sensitive(True)
    else:
      self.send_button.set_sensitive(False)
      
  def gen_prepared_messages(self):
    import base64
    for row in self.recipient_store:
      recipient = row[0]
      rec_name = row[1]
      envelope = models.dmEnvelope()
      envelope.dbIDRecipient = recipient
      envelope.dmRecipient = rec_name
      envelope.dmAnnotation = self.builder.get_object("subject_entry").get_text()
      for name in ("dmLegalTitleLaw","dmLegalTitleYear","dmLegalTitleSect","dmLegalTitlePar",
                   "dmLegalTitlePoint","dmRecipientRefNumber","dmRecipientIdent",
                   "dmSenderRefNumber","dmSenderIdent","dmToHands"):
        text = self.builder.get_object(name).get_text()
        if text:
          setattr(envelope, name, text)
      envelope.dmPersonalDelivery = self.builder.get_object("dmPersonalDelivery").get_active()
      dmfiles = []
      for row in self.attachment_store:
        dmfile = models.dmFile()
        dmfile._dmMimeType = row[3]      
        dmfile._dmFileMetaType = "main"
        dmfile._dmFileDescr = row[0]
        f = file(row[1].decode('utf-8').encode(sys.getfilesystemencoding()), "rb")
        dmfile.dmEncodedContent = base64.standard_b64encode(f.read())
        f.close()
        dmfiles.append(dmfile)
      yield rec_name, recipient, envelope, dmfiles
